@@ -6,7 +6,7 @@ package Dist::Iller;
 
 # ABSTRACT: A Dist::Zilla & Pod::Weaver preprocessor
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1406';
+our $VERSION = '0.1407';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Map Str ConsumerOf/;
@@ -124,16 +124,16 @@ Dist::Iller - A Dist::Zilla & Pod::Weaver preprocessor
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-0.1406"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller/0.1406" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Iller%200.1406"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller/0.1406" alt="CPAN Testers result" /></a>
-<img src="https://img.shields.io/badge/coverage-84.4%-orange.svg" alt="coverage 84.4%" />
+<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-0.1407"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller/0.1407" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller%200.1407"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller/0.1407" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-84.5%-orange.svg" alt="coverage 84.5%" />
 </p>
 
 =end html
 
 =head1 VERSION
 
-Version 0.1406, released 2016-02-18.
+Version 0.1407, released 2016-02-18.
 
 =head1 SYNOPSIS
 
@@ -188,9 +188,11 @@ This is the general syntax of an C<iller.yaml> file:
     plugins:
       # Includes all plugins specified in Dist::Iller::Config::My::Config
       - +config: My::Config
+
       - +plugin: DistIller::MetaGeneratedBy
       - +plugin: AutoVersion
       - +plugin: GatherDir
+
       # 'dir' is a parameter for ShareDir
       - +plugin: ShareDir
         dir: myshare
@@ -205,7 +207,7 @@ This is the general syntax of an C<iller.yaml> file:
       # Same Dist::Iller::Config as in the 'dist' document
       - +config: My::Config
 
-      # Use PluginBundles, but they need ''.
+      # Use PluginBundles
       - +plugin: '@CorePrep'
 
       - +plugin: -SingleEncoding
@@ -237,7 +239,7 @@ Mixes code and configuration.
 
 =item *
 
-Not straightforward to remove specific plugins for a certain distribution
+Not straightforward to remove or replace specific plugins for a certain distribution
 
 =item *
 
@@ -259,7 +261,7 @@ C<Dist::Iller> tries to solve this:
 
 =item *
 
-Dist::Iller configs (similar to PluginBundles) has their own C<iller.yaml> (normally in C<share/>) where plugins are specified. See tests and L<Dist::Iller::Config::Author::CSSON>).
+Dist::Iller configs (similar to PluginBundles) has their own C<iller.yaml> (normally in C<share/>) where plugins are specified. See tests and L<Dist::Iller::Config::Author::CSSON>.
 
 =item *
 
@@ -327,7 +329,7 @@ L<Dist::Iller::Config::Author::CSSON>
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Iller>
+Source repository is at L<https://github.com/Csson/p5-Dist-Iller>.
 
 =head1 HOMEPAGE
 
