@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller::Config;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1406';
+our $VERSION = '0.1407';
 
 use Moose::Role;
 use MooseX::AttributeShortcuts;
@@ -34,6 +34,8 @@ has distribution_name => (
     is => 'ro',
     isa => Str,
     predicate => 1,
+    traits => ['Documented'],
+    documentation_order => 0,
 );
 
 sub config_location {
@@ -86,11 +88,11 @@ Dist::Iller::Config
 
 =head1 VERSION
 
-Version 0.1406, released 2016-02-18.
+Version 0.1407, released 2016-02-18.
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Iller>
+Source repository is at L<https://github.com/Csson/p5-Dist-Iller>.
 
 =head1 HOMEPAGE
 
