@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller::Elk;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1406';
+our $VERSION = '0.1407';
 
 use Moose();
 use MooseX::AttributeShortcuts();
@@ -40,11 +40,11 @@ Dist::Iller::Elk
 
 =head1 VERSION
 
-Version 0.1406, released 2016-02-18.
+Version 0.1407, released 2016-02-18.
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Iller>
+Source repository is at L<https://github.com/Csson/p5-Dist-Iller>.
 
 =head1 HOMEPAGE
 
