@@ -5,12 +5,12 @@ use warnings;
 package Dist::Iller::Role::HasPrereqs;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1406';
+our $VERSION = '0.1407';
 
 use Moose::Role;
 use namespace::autoclean;
 use version;
-use Types::Standard qw/ArrayRef InstanceOf/;
+use Types::Standard qw/ArrayRef HashRef InstanceOf/;
 use Dist::Iller::Prereq;
 
 has prereqs => (
@@ -27,6 +27,19 @@ has prereqs => (
         has_prereqs => 'count',
     },
 );
+has default_prereq_versions => (
+    is => 'ro',
+    isa => HashRef,
+    traits => ['Hash'],
+    default => sub { +{ } },
+    handles => {
+        set_default_prereq_version => 'set',
+        get_default_prereq_version => 'get',
+        all_default_prereq_versions => 'kv',
+    },
+);
+
+
 
 # Ensure that we require the highest wanted version
 around add_prereq => sub {
@@ -34,8 +47,17 @@ around add_prereq => sub {
     my $self = shift;
     my $prereq = shift;
 
-    my $already_existing = $self->find_prereq(sub {$_->module eq $prereq->module && $_->phase eq $prereq->phase });
 
+    my $default_version = $self->get_default_prereq_version($prereq->module);
+    if($default_version && !$prereq->version) {
+        my $parsed_default_version = version->parse($default_version);
+
+        if($parsed_default_version > version->parse($prereq->version)) {
+            $prereq->version($default_version);
+        }
+    }
+
+    my $already_existing = $self->find_prereq(sub {$_->module eq $prereq->module && $_->phase eq $prereq->phase });
     if($already_existing) {
         my $old_version = version->parse($already_existing->version);
         my $new_version = version->parse($prereq->version);
@@ -109,11 +131,11 @@ Dist::Iller::Role::HasPrereqs
 
 =head1 VERSION
 
-Version 0.1406, released 2016-02-18.
+Version 0.1407, released 2016-02-18.
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Iller>
+Source repository is at L<https://github.com/Csson/p5-Dist-Iller>.
 
 =head1 HOMEPAGE
 
